@@ -11,23 +11,31 @@ typedef Eo Efl_Gfx_Stack;
 #ifndef _EFL_GFX_STACK_EO_TYPES
 #define _EFL_GFX_STACK_EO_TYPES
 
+#ifndef EFL_GFX_STACK_LAYER_MIN
+/** bottom-most layer number
+ *
+ * @ingroup Efl_Gfx_Stack_Layer
+ */
+#define EFL_GFX_STACK_LAYER_MIN -32768 /* +32768 */
+#endif
+
+#ifndef EFL_GFX_STACK_LAYER_MAX
+/** top-most layer number
+ *
+ * @ingroup Efl_Gfx_Stack_Layer
+ */
+#define EFL_GFX_STACK_LAYER_MAX 32767
+#endif
+
 
 #endif
-#define EFL_GFX_STACK_INTERFACE efl_gfx_stack_interface_get()
-
-EWAPI const Eo_Class *efl_gfx_stack_interface_get(void);
-
-/**
- * @brief Retrieves the layer of its canvas that the given object is part of.
- *
- * See also @ref efl_gfx_stack_layer_set()
- *
- * @return The number of the layer to place the object on. Must be between
- * #EVAS_LAYER_MIN and #EVAS_LAYER_MAX.
+/** Efl graphics stack interface
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI short efl_gfx_stack_layer_get(const Eo *obj);
+#define EFL_GFX_STACK_INTERFACE efl_gfx_stack_interface_get()
+
+EWAPI const Efl_Class *efl_gfx_stack_interface_get(void);
 
 /**
  * @brief Sets the layer of its canvas that the given object will be part of.
@@ -47,12 +55,24 @@ EOAPI short efl_gfx_stack_layer_get(const Eo *obj);
  * See also @ref efl_gfx_stack_layer_get()
  *
  * @param[in] l The number of the layer to place the object on. Must be between
- * #EVAS_LAYER_MIN and #EVAS_LAYER_MAX.
+ * #EFL_GFX_STACK_LAYER_MIN and #EFL_GFX_STACK_LAYER_MAX.
  *
  * @ingroup Efl_Gfx_Stack
  */
 EOAPI void efl_gfx_stack_layer_set(Eo *obj, short l);
 
+/**
+ * @brief Retrieves the layer of its canvas that the given object is part of.
+ *
+ * See also @ref efl_gfx_stack_layer_set()
+ *
+ * @return The number of the layer to place the object on. Must be between
+ * #EFL_GFX_STACK_LAYER_MIN and #EFL_GFX_STACK_LAYER_MAX.
+ *
+ * @ingroup Efl_Gfx_Stack
+ */
+EOAPI short efl_gfx_stack_layer_get(const Eo *obj);
+
 /**
  * @brief Get the Evas object stacked right below @c obj
  *
@@ -62,12 +82,12 @@ EOAPI void efl_gfx_stack_layer_set(Eo *obj, short l);
  * See also @ref efl_gfx_stack_layer_get(), @ref efl_gfx_stack_layer_set() and
  * @ref efl_gfx_stack_below_get()
  *
- * @return the #Efl_Gfx_Stack directly below @c obj, if any, or @c null, if
+ * @return The #Efl_Gfx_Stack directly below @c obj, if any, or @c null, if
  * none
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI Efl_Gfx_Stack *efl_gfx_stack_below_get(const Eo *obj);
+EOAPI Efl_Gfx_Stack *efl_gfx_stack_below_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Get the Evas object stacked right above @c obj
@@ -78,12 +98,12 @@ EOAPI Efl_Gfx_Stack *efl_gfx_stack_below_get(const Eo *obj);
  * See also @ref efl_gfx_stack_layer_get(), @ref efl_gfx_stack_layer_set() and
  * @ref efl_gfx_stack_below_get()
  *
- * @return the #Efl_Gfx_Stack directly below @c obj, if any, or @c null, if
+ * @return The #Efl_Gfx_Stack directly below @c obj, if any, or @c null, if
  * none
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI Efl_Gfx_Stack *efl_gfx_stack_above_get(const Eo *obj);
+EOAPI Efl_Gfx_Stack *efl_gfx_stack_above_get(const Eo *obj) EINA_WARN_UNUSED_RESULT;
 
 /**
  * @brief Stack @c obj immediately @c below
@@ -105,11 +125,11 @@ EOAPI Efl_Gfx_Stack *efl_gfx_stack_above_get(const Eo *obj);
  * See also @ref efl_gfx_stack_layer_get(), @ref efl_gfx_stack_layer_set() and
  * @ref efl_gfx_stack_below()
  *
- * @param[in] below the object below which to stack
+ * @param[in] below The object below which to stack
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void efl_gfx_stack_below(Eo *obj, Efl_Gfx_Stack *below);
+EOAPI void efl_gfx_stack_below(Eo *obj, Efl_Gfx_Stack *below) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Raise @c obj to the top of its layer.
@@ -144,11 +164,11 @@ EOAPI void efl_gfx_stack_raise(Eo *obj);
  * See also @ref efl_gfx_stack_layer_get(), @ref efl_gfx_stack_layer_set() and
  * @ref efl_gfx_stack_below()
  *
- * @param[in] above the object above which to stack
+ * @param[in] above The object above which to stack
  *
  * @ingroup Efl_Gfx_Stack
  */
-EOAPI void efl_gfx_stack_above(Eo *obj, Efl_Gfx_Stack *above);
+EOAPI void efl_gfx_stack_above(Eo *obj, Efl_Gfx_Stack *above) EINA_ARG_NONNULL(2);
 
 /**
  * @brief Lower @c obj to the bottom of its layer.
@@ -163,7 +183,7 @@ EOAPI void efl_gfx_stack_above(Eo *obj, Efl_Gfx_Stack *above);
  */
 EOAPI void efl_gfx_stack_lower(Eo *obj);
 
-EOAPI extern const Eo_Event_Description _EFL_GFX_EVENT_RESTACK;
+EWAPI extern const Efl_Event_Description _EFL_GFX_EVENT_RESTACK;
 
 /** Object stacking was changed.
  *
