@@ -23,40 +23,40 @@ typedef Eo Efl_Ui_Win;
  */
 typedef enum
 {
-  EFL_UI_WIN_UNKNOWN = -1,
-  EFL_UI_WIN_BASIC, /** A normal window. Indicates a normal, top-level window.
+  EFL_UI_WIN_UNKNOWN = -1 /* +1 */, /**< Default, unknown, type */
+  EFL_UI_WIN_BASIC, /**< A normal window. Indicates a normal, top-level window.
                      * Almost every window will be created with this type. */
-  EFL_UI_WIN_DIALOG_BASIC, /** Used for simple dialog windows. */
-  EFL_UI_WIN_DESKTOP, /** For special desktop windows, like a background window
+  EFL_UI_WIN_DIALOG_BASIC, /**< Used for simple dialog windows. */
+  EFL_UI_WIN_DESKTOP, /**< For special desktop windows, like a background window
                        * holding desktop icons. */
-  EFL_UI_WIN_DOCK, /** The window is used as a dock or panel. Usually would be
+  EFL_UI_WIN_DOCK, /**< The window is used as a dock or panel. Usually would be
                     * kept on top of any other window by the Window Manager. */
-  EFL_UI_WIN_TOOLBAR, /** The window is used to hold a floating toolbar, or
+  EFL_UI_WIN_TOOLBAR, /**< The window is used to hold a floating toolbar, or
                        * similar. */
-  EFL_UI_WIN_MENU, /** Similar to #ELM_WIN_TOOLBAR. */
-  EFL_UI_WIN_UTILITY, /** A persistent utility window, like a toolbox or
+  EFL_UI_WIN_MENU, /**< Similar to #ELM_WIN_TOOLBAR. */
+  EFL_UI_WIN_UTILITY, /**< A persistent utility window, like a toolbox or
                        * palette. */
-  EFL_UI_WIN_SPLASH, /** Splash window for a starting up application. */
-  EFL_UI_WIN_DROPDOWN_MENU, /** The window is a dropdown menu, as when an
+  EFL_UI_WIN_SPLASH, /**< Splash window for a starting up application. */
+  EFL_UI_WIN_DROPDOWN_MENU, /**< The window is a dropdown menu, as when an
                              *  entry in a menubar is clicked. This hint exists
                              * for completion only, as the EFL way of
                              * implementing a menu would not normally use a
                              * separate window for its contents. */
-  EFL_UI_WIN_POPUP_MENU, /** Like #ELM_WIN_DROPDOWN_MENU, but for the menu
+  EFL_UI_WIN_POPUP_MENU, /**< Like #ELM_WIN_DROPDOWN_MENU, but for the menu
                           * triggered by right-clicking an object. */
-  EFL_UI_WIN_TOOLTIP, /** The window is a tooltip. A short piece of explanatory
+  EFL_UI_WIN_TOOLTIP, /**< The window is a tooltip. A short piece of explanatory
                        * text that typically appear after the mouse cursor
                        * hovers over an object for a while. Typically not very
                        * commonly used in the EFL. */
-  EFL_UI_WIN_NOTIFICATION, /** A notification window, like a warning about
+  EFL_UI_WIN_NOTIFICATION, /**< A notification window, like a warning about
                             * battery life or a new E-Mail received. */
-  EFL_UI_WIN_COMBO, /** A window holding the contents of a combo box. Not
+  EFL_UI_WIN_COMBO, /**< A window holding the contents of a combo box. Not
                      * usually used in the EFL. */
-  EFL_UI_WIN_DND, /** Used to indicate the window is a representation of an
+  EFL_UI_WIN_DND, /**< Used to indicate the window is a representation of an
                    * object being dragged across different windows, or even
                    * applications. Typically used with elm_win_override_set().
                    */
-  EFL_UI_WIN_INLINED_IMAGE, /** The window is rendered onto an image buffer. No
+  EFL_UI_WIN_INLINED_IMAGE, /**< The window is rendered onto an image buffer. No
                              * actual window is created for this type, instead
                              * the window and all of its contents will be
                              * rendered to an image buffer. This allows to have
@@ -66,17 +66,21 @@ typedef enum
                              * is the only type of window that requires the
                              * parent parameter of @ref elm_win_add to be a
                              * valid @ref Efl_Canvas_Object. */
-  EFL_UI_WIN_SOCKET_IMAGE, /** The window is rendered onto an image buffer and
+  EFL_UI_WIN_SOCKET_IMAGE, /**< The window is rendered onto an image buffer and
                             * can be shown other process's plug image object.
                             * No actual window is created for this type,
                             * instead the window and all of its contents will
                             * be rendered to an image buffer and can be shown
                             * other process's plug image object. */
-  EFL_UI_WIN_FAKE /** This window was created using a pre-existing canvas. The
-                   * window widget can be deleted, but the canvas must be
-                   * managed externally.
-                   *
-                   * @since 1.13 */
+  EFL_UI_WIN_FAKE, /**< This window was created using a pre-existing canvas. The
+                    * window widget can be deleted, but the canvas must be
+                    * managed externally.
+                    *
+                    * @since 1.13 */
+  EFL_UI_WIN_NAVIFRAME_BASIC /**< Used for naviframe style replacement with a
+                              * back button instead of a close button.
+                              *
+                              * @since 1.19 */
 } Efl_Ui_Win_Type;
 
 /**
@@ -89,22 +93,22 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_KEYBOARD_UNKNOWN = 0, /** Unknown keyboard state */
-  EFL_UI_WIN_KEYBOARD_OFF, /** Request to deactivate the keyboard */
-  EFL_UI_WIN_KEYBOARD_ON, /** Enable keyboard with default layout */
-  EFL_UI_WIN_KEYBOARD_ALPHA, /** Alpha (a-z) keyboard layout */
-  EFL_UI_WIN_KEYBOARD_NUMERIC, /** Numeric keyboard layout */
-  EFL_UI_WIN_KEYBOARD_PIN, /** PIN keyboard layout */
-  EFL_UI_WIN_KEYBOARD_PHONE_NUMBER, /** Phone keyboard layout */
-  EFL_UI_WIN_KEYBOARD_HEX, /** Hexadecimal numeric keyboard layout */
-  EFL_UI_WIN_KEYBOARD_TERMINAL, /** Full (QWERTY) keyboard layout */
-  EFL_UI_WIN_KEYBOARD_PASSWORD, /** Password keyboard layout */
-  EFL_UI_WIN_KEYBOARD_IP, /** IP keyboard layout */
-  EFL_UI_WIN_KEYBOARD_HOST, /** Host keyboard layout */
-  EFL_UI_WIN_KEYBOARD_FILE, /** File keyboard layout */
-  EFL_UI_WIN_KEYBOARD_URL, /** URL keyboard layout */
-  EFL_UI_WIN_KEYBOARD_KEYPAD, /** Keypad layout */
-  EFL_UI_WIN_KEYBOARD_J2ME /** J2ME keyboard layout */
+  EFL_UI_WIN_KEYBOARD_UNKNOWN = 0, /**< Unknown keyboard state */
+  EFL_UI_WIN_KEYBOARD_OFF, /**< Request to deactivate the keyboard */
+  EFL_UI_WIN_KEYBOARD_ON, /**< Enable keyboard with default layout */
+  EFL_UI_WIN_KEYBOARD_ALPHA, /**< Alpha (a-z) keyboard layout */
+  EFL_UI_WIN_KEYBOARD_NUMERIC, /**< Numeric keyboard layout */
+  EFL_UI_WIN_KEYBOARD_PIN, /**< PIN keyboard layout */
+  EFL_UI_WIN_KEYBOARD_PHONE_NUMBER, /**< Phone keyboard layout */
+  EFL_UI_WIN_KEYBOARD_HEX, /**< Hexadecimal numeric keyboard layout */
+  EFL_UI_WIN_KEYBOARD_TERMINAL, /**< Full (QWERTY) keyboard layout */
+  EFL_UI_WIN_KEYBOARD_PASSWORD, /**< Password keyboard layout */
+  EFL_UI_WIN_KEYBOARD_IP, /**< IP keyboard layout */
+  EFL_UI_WIN_KEYBOARD_HOST, /**< Host keyboard layout */
+  EFL_UI_WIN_KEYBOARD_FILE, /**< File keyboard layout */
+  EFL_UI_WIN_KEYBOARD_URL, /**< URL keyboard layout */
+  EFL_UI_WIN_KEYBOARD_KEYPAD, /**< Keypad layout */
+  EFL_UI_WIN_KEYBOARD_J2ME /**< J2ME keyboard layout */
 } Efl_Ui_Win_Keyboard_Mode;
 
 /** Defines the type indicator that can be shown
@@ -113,19 +117,19 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_INDICATOR_TYPE_UNKNOWN = 0, /** Unknown indicator type */
-  EFL_UI_WIN_INDICATOR_BG_OPAQUE, /** The icon of indicator is opaque, the
+  EFL_UI_WIN_INDICATOR_TYPE_UNKNOWN = 0, /**< Unknown indicator type */
+  EFL_UI_WIN_INDICATOR_BG_OPAQUE, /**< The icon of indicator is opaque, the
                                    * background of indicator is also opaque.
-                                   *  The content of window is located the end
+                                   * The content of window is located the end
                                    * of indicator. The area of indicator and
                                    * window content are not overlapped */
-  EFL_UI_WIN_INDICATOR_BG_TRANSPARENT, /** The icon of indicator is opaque, but
+  EFL_UI_WIN_INDICATOR_BG_TRANSPARENT, /**< The icon of indicator is opaque, but
                                         * the background is transparent. The
                                         * content of window is located under
                                         * the indicator in Z-order. The area of
                                         * indicator and window content are
                                         * overlapped */
-  EFL_UI_WIN_INDICATOR_HIDDEN /** The indicator is hidden, So user can see only
+  EFL_UI_WIN_INDICATOR_HIDDEN /**< The indicator is hidden, So user can see only
                                * the content of window like the video mode. If
                                * user flicks the upper side of window, the
                                * incator is shown temporarily. */
@@ -138,18 +142,18 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_KEYGRAB_UNKNOWN = 0, /** Unknown keygrab mode */
-  EFL_UI_WIN_KEYGRAB_SHARED = 256 /* 1 << 8 */, /** Getting the grabbed-key
+  EFL_UI_WIN_KEYGRAB_UNKNOWN = 0, /**< Unknown keygrab mode */
+  EFL_UI_WIN_KEYGRAB_SHARED = 256 /* 1 >> 8 */, /**< Getting the grabbed-key
                                                  * together with the other
                                                  * client windows */
-  EFL_UI_WIN_KEYGRAB_TOPMOST = 512 /* 1 << 9 */, /** Getting the grabbed-key
+  EFL_UI_WIN_KEYGRAB_TOPMOST = 512 /* 1 >> 9 */, /**< Getting the grabbed-key
                                                   * only when window is top of
                                                   * the stack */
-  EFL_UI_WIN_KEYGRAB_EXCLUSIVE = 1024 /* 1 << 10 */, /** Getting the
+  EFL_UI_WIN_KEYGRAB_EXCLUSIVE = 1024 /* 1 >> 10 */, /**< Getting the
                                                       * grabbed-key exclusively
                                                       * regardless of window's
                                                       * position */
-  EFL_UI_WIN_KEYGRAB_OVERRIDE_EXCLUSIVE = 2048 /* 1 << 11 */ /** Getting the grabbed-key exclusively
+  EFL_UI_WIN_KEYGRAB_OVERRIDE_EXCLUSIVE = 2048 /* 1 >> 11 */ /**< Getting the grabbed-key exclusively
                                                               * regardless of window's position.
                                                               * Being overrided the grab by the
                                                               * other client window */
@@ -161,8 +165,8 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_MODAL_NONE = 0, /** The window is not modal window. */
-  EFL_UI_WIN_MODAL_MODAL /** The window is modal window. */
+  EFL_UI_WIN_MODAL_NONE = 0, /**< The window is not modal window. */
+  EFL_UI_WIN_MODAL_MODAL /**< The window is modal window. */
 } Efl_Ui_Win_Modal_Mode;
 
 /** Defines the mode of a urgent window.
@@ -171,13 +175,46 @@ typedef enum
  */
 typedef enum
 {
-  EFL_UI_WIN_URGENT_NONE = 0, /** The window is not a urgent window. */
-  EFL_UI_WIN_URGENT_URGENT /** The window is a urgent window. */
+  EFL_UI_WIN_URGENT_NONE = 0, /**< The window is not a urgent window. */
+  EFL_UI_WIN_URGENT_URGENT /**< The window is a urgent window. */
 } Efl_Ui_Win_Urgent_Mode;
 
+/**
+ * @brief Define the move or resize mode of window.
+ *
+ * The user can request the display server to start moving or resizing the
+ * window by combining these modes. However, only limited combinations are
+ * allowed.
+ *
+ * Currently, only the following 9 combinations are allowed, and possibly more
+ * combinations may be added in the future: 1. move, 2. top, 3. bottom, 4.
+ * left, 5. right, 6. top | left, 7. top | right, 8. bottom | left, 9. bottom |
+ * right.
+ *
+ * @since 1.19
+ *
+ * @ingroup Efl_Ui_Win
+ */
+typedef enum
+{
+  EFL_UI_WIN_MOVE_RESIZE_MOVE = 1, /**< Start moving window */
+  EFL_UI_WIN_MOVE_RESIZE_TOP = 2 /* 1 >> 1 */, /**< Start resizing window to the
+                                                * top */
+  EFL_UI_WIN_MOVE_RESIZE_BOTTOM = 4 /* 1 >> 2 */, /**< Start resizing window to
+                                                   * the bottom */
+  EFL_UI_WIN_MOVE_RESIZE_LEFT = 8 /* 1 >> 3 */, /**< Start resizing window to
+                                                 * the left */
+  EFL_UI_WIN_MOVE_RESIZE_RIGHT = 16 /* 1 >> 4 */ /**< Start resizing window to
+                                                  * the right */
+} Efl_Ui_Win_Move_Resize_Mode;
+
 
 #endif
 
+
+
+
+
 /**
  * @brief Sets the keyboard mode of the window.
  *
@@ -219,6 +256,8 @@ EAPI void elm_win_wm_rotation_available_rotations_set(Efl_Ui_Win *obj, const int
  * @param[out] rotations The array of rotation value.
  * @param[out] count The size of the rotations array.
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @since 1.9
  *
  * @ingroup Efl_Ui_Win
@@ -336,7 +375,10 @@ EAPI Eina_Bool elm_win_focus_highlight_animate_get(const Efl_Ui_Win *obj);
  */
 EAPI void elm_win_prop_focus_skip_set(Efl_Ui_Win *obj, Eina_Bool skip);
 
-/** Get whether a window has focus.
+/**
+ * @brief Get whether a window has focus.
+ *
+ * @return @c true if window has focus, @c false otherwise
  *
  * @ingroup Efl_Ui_Win
  */
@@ -356,8 +398,8 @@ EAPI Eina_Bool elm_win_focus_get(const Efl_Ui_Win *obj);
  * is @c false, then the window will not be destroyed and is up to the program
  * to do so when it's required.
  *
- * @param[in] autodel If true, the window will automatically delete itself when
- * closed.
+ * @param[in] autodel If @c true, the window will automatically delete itself
+ * when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -366,7 +408,7 @@ EAPI void elm_win_autodel_set(Efl_Ui_Win *obj, Eina_Bool autodel);
 /**
  * @brief Get the window's autodel state.
  *
- * @return If true, the window will automatically delete itself when closed.
+ * @return If @c true, the window will automatically delete itself when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -386,8 +428,8 @@ EAPI Eina_Bool elm_win_autodel_get(const Efl_Ui_Win *obj);
  * @note @ref elm_win_autodel_get and @c autohide are not mutually exclusive.
  * The window will be deleted if both are set to @c true.
  *
- * @param[in] autohide If true, the window will automatically hide itself when
- * closed.
+ * @param[in] autohide If @c true, the window will automatically hide itself
+ * when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -407,7 +449,7 @@ EAPI void elm_win_autohide_set(Efl_Ui_Win *obj, Eina_Bool autohide);
  * @note @ref elm_win_autodel_get and @c autohide are not mutually exclusive.
  * The window will be deleted if both are set to @c true.
  *
- * @return If true, the window will automatically hide itself when closed.
+ * @return If @c true, the window will automatically hide itself when closed.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -444,7 +486,7 @@ EAPI const Efl_Canvas_Object *elm_win_icon_object_get(const Efl_Ui_Win *obj);
 /**
  * @brief Set the iconified state of a window.
  *
- * @param[in] iconified If true, the window is iconified.
+ * @param[in] iconified If @c true, the window is iconified.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -453,7 +495,7 @@ EAPI void elm_win_iconified_set(Efl_Ui_Win *obj, Eina_Bool iconified);
 /**
  * @brief Get the iconified state of a window.
  *
- * @return If true, the window is iconified.
+ * @return If @c true, the window is iconified.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -462,7 +504,7 @@ EAPI Eina_Bool elm_win_iconified_get(const Efl_Ui_Win *obj);
 /**
  * @brief Set the maximized state of a window.
  *
- * @param[in] maximized If true, the window is maximized.
+ * @param[in] maximized If @c true, the window is maximized.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -471,7 +513,7 @@ EAPI void elm_win_maximized_set(Efl_Ui_Win *obj, Eina_Bool maximized);
 /**
  * @brief Get the maximized state of a window.
  *
- * @return If true, the window is maximized.
+ * @return If @c true, the window is maximized.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -501,7 +543,7 @@ EAPI Eina_Bool elm_win_fullscreen_get(const Efl_Ui_Win *obj);
  * Hints the Window Manager that the window in @c obj should be left fixed at
  * its position even when the virtual desktop it's on moves or changes.
  *
- * @param[in] sticky If true, the window's sticky state is enabled.
+ * @param[in] sticky If @c true, the window's sticky state is enabled.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -510,22 +552,26 @@ EAPI void elm_win_sticky_set(Efl_Ui_Win *obj, Eina_Bool sticky);
 /**
  * @brief Get the sticky state of the window.
  *
- * @return If true, the window's sticky state is enabled.
+ * @return If @c true, the window's sticky state is enabled.
  *
  * @ingroup Efl_Ui_Win
  */
 EAPI Eina_Bool elm_win_sticky_get(const Efl_Ui_Win *obj);
 
+
+
+
+
 /**
  * @brief Set the noblank property of a window.
  *
- * The "noblank" property is a way to request the display on which the windowis
- * shown does not blank, screensave or otherwise hide or obscure the window. It
- * is intended for uses such as media playback on a television where a user may
- * not want to be interrupted by an idle screen. The noblank property may have
- * no effect if the window is iconified/minimized or hidden.
+ * The "noblank" property is a way to request the display on which the window
+ * is shown does not blank, screensave or otherwise hide or obscure the window.
+ * It is intended for uses such as media playback on a television where a user
+ * may not want to be interrupted by an idle screen. The noblank property may
+ * have no effect if the window is iconified/minimized or hidden.
  *
- * @param[in] noblank If true, the window is set to noblank.
+ * @param[in] noblank If @c true, the window is set to noblank.
  *
  * @since 1.11
  *
@@ -536,7 +582,7 @@ EAPI void elm_win_noblank_set(Efl_Ui_Win *obj, Eina_Bool noblank);
 /**
  * @brief Get the noblank property of a window.
  *
- * @return If true, the window is set to noblank.
+ * @return If @c true, the window is set to noblank.
  *
  * @since 1.11
  *
@@ -550,7 +596,7 @@ EAPI Eina_Bool elm_win_noblank_get(const Efl_Ui_Win *obj);
  * This function requests the Window Manager to not draw any decoration around
  * the window.
  *
- * @param[in] borderless If true, the window is borderless.
+ * @param[in] borderless If @c true, the window is borderless.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -559,7 +605,7 @@ EAPI void elm_win_borderless_set(Efl_Ui_Win *obj, Eina_Bool borderless);
 /**
  * @brief Get the borderless state of a window.
  *
- * @return If true, the window is borderless.
+ * @return If @c true, the window is borderless.
  *
  * @ingroup Efl_Ui_Win
  */
@@ -586,6 +632,7 @@ EAPI void elm_win_role_set(Efl_Ui_Win *obj, const char *role);
  */
 EAPI const char *elm_win_role_get(const Efl_Ui_Win *obj);
 
+
 /**
  * @brief The window name.
  *
@@ -598,12 +645,15 @@ EAPI const char *elm_win_role_get(const Efl_Ui_Win *obj);
  *
  * No description supplied.
  *
+ * @return Window name
+ *
  * @since 1.18
  *
  * @ingroup Efl_Ui_Win
  */
 EAPI const char *elm_win_name_get(const Efl_Ui_Win *obj);
 
+
 /**
  * @brief The type of the window.
  *
@@ -616,15 +666,18 @@ EAPI const char *elm_win_name_get(const Efl_Ui_Win *obj);
  *
  * If the object is not window object, return #ELM_WIN_UNKNOWN.
  *
+ * @return Window type
+ *
  * @ingroup Efl_Ui_Win
  */
 EAPI Efl_Ui_Win_Type elm_win_type_get(const Efl_Ui_Win *obj);
 
+
 /**
  * @brief The hardware acceleration preference for this window.
  *
  * This is a constructor function, and can only be called before
- * @ref Eo.Base.finalize.
+ * @ref Efl.Object.finalize.
  *
  * This property overrides the global EFL configuration option
  * "accel_preference" for this single window, and accepts the same syntax.
@@ -663,6 +716,8 @@ EAPI Efl_Ui_Win_Type elm_win_type_get(const Efl_Ui_Win *obj);
  * This will return the value of "accel_preference" when the window was
  * created.
  *
+ * @return Acceleration
+ *
  * @since 1.18
  *
  * @ingroup Efl_Ui_Win
@@ -687,6 +742,8 @@ EAPI void elm_win_available_profiles_set(Efl_Ui_Win *obj, const char **profiles,
  * @param[out] profiles The string array of available profiles.
  * @param[out] count The number of members in profiles.
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @since 1.8
  *
  * @ingroup Efl_Ui_Win
@@ -733,6 +790,8 @@ EAPI Eina_Bool elm_win_alpha_get(const Efl_Ui_Win *obj);
  * service all users can connect to, otherwise the service is private to the
  * user id that created the service.
  *
+ * @return @c true on success, @c false otherwise
+ *
  * @ingroup Efl_Ui_Win
  */
 EAPI Eina_Bool elm_win_socket_listen(Efl_Ui_Win *obj, const char *svcname, int svcnum, Eina_Bool svcsys);
@@ -768,96 +827,59 @@ EAPI void elm_win_raise(Efl_Ui_Win *obj);
  * This function centers window @c obj horizontally and/or vertically based on
  * the values of @c h and @c v.
  *
- * @param[in] h If true, center horizontally. If false, do not change
+ * @param[in] h If @c true, center horizontally. If @c false, do not change
  * horizontal location.
- * @param[in] v If true, center vertically. If false, do not change vertical
- * location.
+ * @param[in] v If @c true, center vertically. If @c false, do not change
+ * vertical location.
  *
  * @ingroup Efl_Ui_Win
  */
 EAPI void elm_win_center(Efl_Ui_Win *obj, Eina_Bool h, Eina_Bool v);
 
-/**
- * @brief Set keygrab value of the window
- *
- * This function grabs the @c key of window using @c grab_mode.
- *
- * @param[in] key This string is the keyname to grab.
- * @param[in] modifiers This is for the keymask feature. Currently this feature
- * is not supported.
- * @param[in] not_modifiers This is for the keymask feature. Currently this
- * feature is not supported.
- * @param[in] proirity This is for the priority of keygrab. Currently this
- * feature is not supported.
- * @param[in] grab_mode According to the grabmode, it can grab key differently.
- *
- * @ingroup Efl_Ui_Win
- */
-EAPI Eina_Bool elm_win_keygrab_set(Efl_Ui_Win *obj, const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers, int proirity, Efl_Ui_Win_Keygrab_Mode grab_mode);
+
 
 /**
- * @brief Unset keygrab value of the window
+ * @brief Start moving or resizing the window.
  *
- * This function unset keygrab value. Ungrab @c key of window.
+ * The user can request the display server to start moving or resizing the
+ * window by combining modes from @ref Efl_Ui_Win_Move_Resize_Mode. This API
+ * can only be called if none of the following conditions is true:
  *
- * @param[in] key This string is the keyname to grab.
- * @param[in] modifiers This is for the keymask feature. Currently this feature
- * is not supported.
- * @param[in] not_modifiers This is for the keymask feature. Currently this
- * feature is not supported.
+ * 1. Called in the absence of a pointer down event, 2. Called more than once
+ * before a pointer up event, 3. Called when the window is already being
+ * resized or moved, 4. Called with an unsupported combination of modes.
+ *
+ * Right usage: 1. Pointer (mouse or touch) down event, 2.
+ * @ref elm_win_move_resize_start called only once with a supported mode, 3.
+ * Pointer (mouse or touch) up event.
+ *
+ * If a pointer up event occurs after calling the function, it automatically
+ * ends the window move and resize operation.
+ *
+ * Currently, only the following 9 combinations are allowed, and possibly more
+ * combinations may be added in the future: 1. @ref EFL_UI_WIN_MOVE_RESIZE_MOVE
+ * 2. @ref EFL_UI_WIN_MOVE_RESIZE_TOP 3. @ref EFL_UI_WIN_MOVE_RESIZE_BOTTOM 4.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_LEFT 5. @ref EFL_UI_WIN_MOVE_RESIZE_RIGHT 6.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_TOP | @ref EFL_UI_WIN_MOVE_RESIZE_LEFT 7.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_TOP | @ref EFL_UI_WIN_MOVE_RESIZE_RIGHT 8.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_BOTTOM | @ref EFL_UI_WIN_MOVE_RESIZE_LEFT 9.
+ * @ref EFL_UI_WIN_MOVE_RESIZE_BOTTOM | @ref EFL_UI_WIN_MOVE_RESIZE_RIGHT
+ *
+ * In particular move and resize can not happen simultaneously.
+ *
+ * @note the result of this API can only guarantee that the request has been
+ * forwarded to the server, but there is no guarantee that the request can be
+ * processed by the display server.
+ *
+ * @param[in] mode The requested move or resize mode.
+ *
+ * @return @c true if the request was successfully sent to the display server,
+ * @c false in case of error.
+ *
+ * @since 1.19
  *
  * @ingroup Efl_Ui_Win
  */
-EAPI Eina_Bool elm_win_keygrab_unset(Efl_Ui_Win *obj, const char *key, Evas_Modifier_Mask modifiers, Evas_Modifier_Mask not_modifiers);
-
-/**
- * @brief Notify the compositor that a uri should be preloaded
- *
- * @param[in] uri This is the uri to notify with
- *
- * @since 1.18
- *
- * @ingroup Efl_Ui_Win
- */
-EAPI void elm_win_teamwork_uri_preload(Efl_Ui_Win *obj, const char *uri);
-
-/**
- * @brief Notify the compositor that a uri should be displayed
- *
- * Sends the current mouse coordinates as a hint for displaying the related uri
- * in the compositor.
- *
- * @param[in] uri This is the uri to notify with
- *
- * @since 1.18
- *
- * @ingroup Efl_Ui_Win
- */
-EAPI void elm_win_teamwork_uri_show(Efl_Ui_Win *obj, const char *uri);
-
-/**
- * @brief Notify the compositor that a uri should be hidden
- *
- * Hides any uri-related media displayed in the compositor through previous
- * @ref elm_win_teamwork_uri_show request
- *
- * @since 1.18
- *
- * @ingroup Efl_Ui_Win
- */
-EAPI void elm_win_teamwork_uri_hide(Efl_Ui_Win *obj);
-
-/**
- * @brief Notify the compositor that a uri should be opened
- *
- * Use the compositor's default application to open a uri
- *
- * @param[in] uri This is the uri to open
- *
- * @since 1.18
- *
- * @ingroup Efl_Ui_Win
- */
-EAPI void elm_win_teamwork_uri_open(Efl_Ui_Win *obj, const char *uri);
+EAPI Eina_Bool elm_win_move_resize_start(Efl_Ui_Win *obj, Efl_Ui_Win_Move_Resize_Mode mode);
 
 #endif
