@@ -15,7 +15,7 @@ typedef Eo Elm_List;
  * @brief Set list's resizing behavior, transverse axis scrolling and items
  * cropping. See each mode's description for more details.
  *
- * @note Default value is @ref Elm_List_Mode.ELM_LIST_SCROLL.
+ * @note Default value is @ref ELM_LIST_SCROLL.
  *
  * Values here don't work as bitmasks -- only one can be chosen at a time.
  *
@@ -25,31 +25,31 @@ typedef Eo Elm_List;
  */
 typedef enum
 {
-  ELM_LIST_COMPRESS = 0, /** The list won't set any of its size hints to inform
+  ELM_LIST_COMPRESS = 0, /**< The list won't set any of its size hints to inform
                           * how a possible container should resize it. Then, if
                           * it's not created as a "resize object", it might end
                           * with zeroed dimensions. The list will respect the
                           * container's geometry and, if any of its items won't
                           * fit into its transverse axis, one won't be able to
                           * scroll it in that direction. */
-  ELM_LIST_SCROLL, /** Default value. This is the same as #ELM_LIST_COMPRESS,
+  ELM_LIST_SCROLL, /**< Default value. This is the same as #ELM_LIST_COMPRESS,
                     * with the exception that if any of its items won't fit
                     * into its transverse axis, one will be able to scroll it
                     * in that direction. */
-  ELM_LIST_LIMIT, /** Sets a minimum size hint on the list object, so that
+  ELM_LIST_LIMIT, /**< Sets a minimum size hint on the list object, so that
                    * containers may respect it (and resize itself to fit the
                    * child properly). More specifically, a minimum size hint
                    * will be set for its transverse axis, so that the largest
                    * item in that direction fits well. This is naturally bound
                    * by the list object's maximum size hints, set externally.
                    */
-  ELM_LIST_EXPAND, /** Besides setting a minimum size on the transverse axis,
-                    * just like on @ref Elm_List_Mode.ELM_LIST_LIMIT, the list
-                    * will set a minimum size on th longitudinal axis, trying
-                    * to reserve space to all its children to be visible at a
-                    * time. . This is naturally bound by the list object's
-                    * maximum size hints, set externally. */
-  ELM_LIST_LAST /** Indicates error if returned by elm_list_mode_get(). */
+  ELM_LIST_EXPAND, /**< Besides setting a minimum size on the transverse axis,
+                    * just like on @ref ELM_LIST_LIMIT, the list will set a
+                    * minimum size on th longitudinal axis, trying to reserve
+                    * space to all its children to be visible at a time. . This
+                    * is naturally bound by the list object's maximum size
+                    * hints, set externally. */
+  ELM_LIST_LAST /**< Indicates error if returned by elm_list_mode_get(). */
 } Elm_List_Mode;
 
 
@@ -132,7 +132,8 @@ EAPI Elm_Object_Select_Mode elm_list_select_mode_get(const Elm_List *obj);
  * an item or selecting it with a key movement. Clicking on a focusable widget
  * inside an item will couse this particular item to get focus as usual.
  *
- * @param[in] enabled The tree effect status (true = enabled, false = disabled)
+ * @param[in] enabled The tree effect status ($true = enabled, @c false =
+ * disabled)
  *
  * @ingroup Elm_List
  */
@@ -147,7 +148,7 @@ EAPI void elm_list_focus_on_selection_set(Elm_List *obj, Eina_Bool enabled);
  * an item or selecting it with a key movement. Clicking on a focusable widget
  * inside an item will couse this particular item to get focus as usual.
  *
- * @return The tree effect status (true = enabled, false = disabled)
+ * @return The tree effect status ($true = enabled, @c false = disabled)
  *
  * @ingroup Elm_List
  */
@@ -425,7 +426,7 @@ EAPI Elm_Widget_Item *elm_list_item_insert_after(Elm_List *obj, Elm_Widget_Item
  *
  * @ingroup Elm_List
  */
-EAPI Elm_Widget_Item *elm_list_at_xy_item_get(const Elm_List *obj, Evas_Coord x, Evas_Coord y, int *posret);
+EAPI Elm_Widget_Item *elm_list_at_xy_item_get(const Elm_List *obj, int x, int y, int *posret);
 
 /**
  * @brief Append a new item to the list object.
