@@ -13,9 +13,12 @@ typedef Eo Elm_Panel_Internal_Part;
 
 
 #endif
+/** Elementary panel internal part class
+ *
+ * @ingroup Elm_Panel_Internal_Part
+ */
 #define ELM_PANEL_INTERNAL_PART_CLASS elm_panel_internal_part_class_get()
 
-EWAPI const Eo_Class *elm_panel_internal_part_class_get(void);
-
+EWAPI const Efl_Class *elm_panel_internal_part_class_get(void);
 
 #endif
