@@ -13,9 +13,13 @@ typedef Eo Elm_View_Form;
 
 
 #endif
+/** Elementary view form class
+ *
+ * @ingroup Elm_View_Form
+ */
 #define ELM_VIEW_FORM_CLASS elm_view_form_class_get()
 
-EWAPI const Eo_Class *elm_view_form_class_get(void);
+EWAPI const Efl_Class *elm_view_form_class_get(void);
 
 /**
  * @brief Set model
@@ -40,5 +44,4 @@ EOAPI void elm_view_form_model_set(Eo *obj, Efl_Model *model);
  */
 EOAPI void elm_view_form_widget_add(Eo *obj, const char *propname, Efl_Canvas_Object *evas);
 
-
 #endif
