@@ -13,9 +13,12 @@ typedef Eo Efl_VG_Root_Node;
 
 
 #endif
+/** Efl vector graphics root node class
+ *
+ * @ingroup Efl_VG_Root_Node
+ */
 #define EFL_VG_ROOT_NODE_CLASS efl_vg_root_node_class_get()
 
-EAPI const Eo_Class *efl_vg_root_node_class_get(void) EINA_CONST;
-
+EWAPI const Efl_Class *efl_vg_root_node_class_get(void);
 
 #endif
