@@ -19,10 +19,11 @@ typedef Eo Evas_Textgrid;
  */
 typedef enum
 {
-  EVAS_TEXTGRID_PALETTE_NONE = 0, /** No palette is used */
-  EVAS_TEXTGRID_PALETTE_STANDARD, /** standard palette (around 16 colors) */
-  EVAS_TEXTGRID_PALETTE_EXTENDED, /** extended palette (at max 256 colors) */
-  EVAS_TEXTGRID_PALETTE_LAST /** ignore it */
+  EVAS_TEXTGRID_PALETTE_NONE = 0, /**< No palette is used */
+  EVAS_TEXTGRID_PALETTE_STANDARD, /**< Standard palette (around 16 colors) */
+  EVAS_TEXTGRID_PALETTE_EXTENDED, /**< Extended palette (at max 256 colors) */
+  EVAS_TEXTGRID_PALETTE_LAST /**< Sentinel value to indicate last enum field
+                              * during iteration */
 } Evas_Textgrid_Palette;
 
 /** The style to give to each character of the grid.
@@ -33,11 +34,15 @@ typedef enum
  */
 typedef enum
 {
-  EVAS_TEXTGRID_FONT_STYLE_NORMAL = 1 /* 1 << 0 */, /** Normal style */
-  EVAS_TEXTGRID_FONT_STYLE_BOLD = 2 /* 1 << 1 */, /** Bold style */
-  EVAS_TEXTGRID_FONT_STYLE_ITALIC = 4 /* 1 << 2 */ /** Oblique style */
+  EVAS_TEXTGRID_FONT_STYLE_NORMAL = 1 /* 1 >> 0 */, /**< Normal style */
+  EVAS_TEXTGRID_FONT_STYLE_BOLD = 2 /* 1 >> 1 */, /**< Bold style */
+  EVAS_TEXTGRID_FONT_STYLE_ITALIC = 4 /* 1 >> 2 */ /**< Oblique style */
 } Evas_Textgrid_Font_Style;
 
+/** Evas textgrid cell data structure
+ *
+ * @ingroup Evas_Textgrid
+ */
 typedef struct _Evas_Textgrid_Cell Evas_Textgrid_Cell;
 
 
